﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using CoreGraphics;
using Syncfusion.SfDataGrid;
using UIKit;

namespace SummaryDemo
{
	



	public class NotificationObject : INotifyPropertyChanged
	{
		
		public void RaisePropertyChanged(string propName)
		{
			if (this.PropertyChanged != null)
				this.PropertyChanged(this, new PropertyChangedEventArgs(propName));
		}

		public event PropertyChangedEventHandler PropertyChanged;

	}

	//this model is used to hold the dictionary values of each row so that it can be referenced from the grid
	public class DynamicModel : INotifyPropertyChanged
	{
		public Dictionary<string, object> _values;
		public object _groupProperty;

		public event PropertyChangedEventHandler PropertyChanged;

		public object GroupProperty
		{
			get
			{
				return _groupProperty;
			}
			set
			{
				_groupProperty = value;
				if (PropertyChanged != null)
					PropertyChanged(this, new PropertyChangedEventArgs("GroupProperty"));
			}
		}

		public Dictionary<string, object> Values
		{
			get
			{
				return _values;
			}
			set
			{
				_values = value;
				if (PropertyChanged != null)
					PropertyChanged(this, new PropertyChangedEventArgs("Values"));
			}

		}


		public DynamicModel()
		{
			this._values = new Dictionary<string, object>();

		}

		public void RefreshGroupProperty(string key)
		{
			object value = null;
			this.Values.TryGetValue(key, out value);
			this.GroupProperty = value;
		}
	}

	public class WrappingSyncHeaderCellRenderer : GridHeaderCellRenderer
	{
		public WrappingSyncHeaderCellRenderer()
		{

		}

		public override void OnInitializeDisplayView(DataColumnBase dataColumn, UIView uiView)
		{
			base.OnInitializeDisplayView(dataColumn, uiView);

			if (uiView as UILabel != null)
			{
				(uiView as UILabel).Text = dataColumn.CellValue.ToString();
				(uiView as UILabel).Lines = 5;
				(uiView as UILabel).LineBreakMode = UILineBreakMode.WordWrap;
				(uiView as UILabel).TextAlignment = UITextAlignment.Center;
			}
		}

	}

	public class FormattedSyncColumn : GridTextColumn
	{
		public string FormatType { get; set; }
		public string FormatMask { get; set; }
		//public ViewColumn Column { get; set; }
		public ColumnSortOrder Order = ColumnSortOrder.None;
		//the image view used in the header, this is needed so that we can hide it in inactive columns
		public UIImageView SortImage { get; set; }

		public FormattedSyncColumn() : base()
		{

		}


	}

	public enum ColumnSortOrder
	{
		Ascending,
		Descending,
		None
	}

}

